@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (c) 2012 - 2016 dak180 and contributors. See
+# Copyright (c) 2012 - 2017 dak180 and contributors. See
 # https://opensource.org/licenses/mit-license.php or the included
 # COPYING.md for licence terms.
 #
@@ -117,11 +117,12 @@ elif [ ! -f "${CACHEFILE}" ] && [ "${CACHEFORCE}" = "1" ]; then
 	exit 1
 fi
 
-# Only use the local keyword if it is there (Solaris we are looking at
+# Only use the local keyword if it is there (ksh we are looking at
 # you).
-if command -v local > /dev/null 2>&1; then
+
+if [ "$(command -v local 2> /dev/null)" = "local" ]; then
 	LOCAL="local"
-elif command -v typeset > /dev/null 2>&1; then
+elif [ "$(command -v typeset 2> /dev/null)" = "typeset" ]; then
 	LOCAL="typeset"
 else
 	LOCAL=""
@@ -624,7 +625,7 @@ VCS_ACTION_STAMP = "${VCS_ACTION_STAMP}"
 VCS_FULL_HASH = "${VCS_FULL_HASH}"
 VCS_SHORT_HASH = "${VCS_SHORT_HASH}"
 
-VCS_WC_MODIFIED = ${VCS_WC_MODIFIED}
+VCS_WC_MODIFIED = ${PY_VCS_WC_MODIFIED}
 
 # end
 EOF
@@ -1235,6 +1236,25 @@ else
 fi
 
 
+# If requested, make a cache file.
+if [ ! -z "${CACHEFILE}" ] && [ ! "${CACHEFORCE}" = "1" ]; then
+	EXTRA_OUTPUT="${EXTRA_NAME}"
+	EXTRA_NAME="VCS_EXTRA"
+	shOutput > "${CACHEFILE}.tmp"
+
+	# Check to see if there have been any actual changes.
+	if [ ! -f "${CACHEFILE}" ]; then
+		mv -f "${CACHEFILE}.tmp" "${CACHEFILE}"
+	elif cmp -s "${CACHEFILE}.tmp" "${CACHEFILE}"; then
+		rm -f "${CACHEFILE}.tmp"
+	else
+		mv -f "${CACHEFILE}.tmp" "${CACHEFILE}"
+	fi
+	EXTRA_NAME="${EXTRA_OUTPUT}"
+fi
+
+
+
 # -s output is handled here.
 if [ ! -z "${VAROUT}" ]; then
 	if [ "${VAROUT}" = "VCS_TYPE" ]; then
@@ -1321,19 +1341,3 @@ if [ ! -z "${AFILETYPE}" ]; then
 		exit 1
 	fi
 fi
-
-
-# If requested, make a cache file.
-if [ ! -z "${CACHEFILE}" ] && [ ! "${CACHEFORCE}" = "1" ]; then
-	EXTRA_NAME="VCS_EXTRA"
-	shOutput > "${CACHEFILE}.tmp"
-
-	# Check to see if there have been any actual changes.
-	if [ ! -f "${CACHEFILE}" ]; then
-		mv -f "${CACHEFILE}.tmp" "${CACHEFILE}"
-	elif cmp -s "${CACHEFILE}.tmp" "${CACHEFILE}"; then
-		rm -f "${CACHEFILE}.tmp"
-	else
-		mv -f "${CACHEFILE}.tmp" "${CACHEFILE}"
-	fi
-fi
